@@ -1139,10 +1139,10 @@ class FlourishInterventionMessageAddView(flourish.form.AddForm):
         self.actions['cancel'].addClass('button-cancel')
 
     def create(self, data):
-        sender = IContact(self.request.principal._person)
-        message = intervention.InterventionMessage(sender, data['recipients'],
-                                                   data['body'],
+        message = intervention.InterventionMessage(data['body'],
                                                    data['subject'])
+        self._sender = IContact(self.request.principal._person)
+        self._recipients = data['recipients']
         return message
 
     def add(self, message):
@@ -1150,6 +1150,10 @@ class FlourishInterventionMessageAddView(flourish.form.AddForm):
         chooser = INameChooser(self.context)
         name = chooser.chooseName('', message)
         self.context[name] = message
+        if self._sender:
+            message.sender.add(IContact(self._sender))
+        for recipient in self._recipients:
+            message.recipients.add(IContact(recipient))
         return message
 
     def nextURL(self):
@@ -1441,11 +1445,12 @@ class FlourishInterventionGoalAddView(flourish.form.AddForm):
     def create(self, data):
         creator = IContact(self.request.principal._person)
         goal = intervention.InterventionGoal(
-            data['goal'], data['timeline'], data['persons_responsible'],
+            data['goal'], data['timeline'],
             data['presenting_concerns'], data['strengths'], data['indicators'],
             data['intervention'],
-            goal_met=data['goal_met'], follow_up_notes=data['follow_up_notes'],
-            creator=creator)
+            goal_met=data['goal_met'], follow_up_notes=data['follow_up_notes'])
+        self._persons_responsible = data['persons_responsible']
+        self._creator = creator
         return goal
 
     def add(self, goal):
@@ -1453,6 +1458,9 @@ class FlourishInterventionGoalAddView(flourish.form.AddForm):
         chooser = INameChooser(self.context)
         name = chooser.chooseName('', goal)
         self.context[name] = goal
+        goal.persons_responsible = self._persons_responsible
+        if self._creator is not None:
+            goal.creator.add(IContact(self._creator))
         return goal
 
     def nextURL(self):
